@@ -2,6 +2,9 @@
 import os,sys,csv
 import hashlib
 
+from pathlib import Path
+from numpy.lib.stride_tricks import as_strided as ast
+
 # regular pythong stuff
 # redundant form interactive computing
 import collections
@@ -367,6 +370,13 @@ def nan_smooth(y,n=5,ens=[],ignore_nans=True):
 
 # normalized version of cross correlation - mimicking matlabs'
 def xcorr(a, b, ds):
+    """
+
+    :param a: x1
+    :param b: x2
+    :param ds: sampling rate
+    :return: corrs, lags
+    """
     S = len(a)
     a_norm = (a - np.mean(a)) / np.std(a)
     b_norm = (b - np.mean(b)) / np.std(b)
@@ -557,7 +567,34 @@ def chopn(seq, n):
     chunks = chop(seq, size)
     return [w for w in chunks if len(w) == size]
 
+# https://gist.github.com/mattjj/5213172
+def chunk_data(data,window_size,overlap_size=0,flatten_inside_window=True):
+    assert data.ndim == 1 or data.ndim == 2
+    if data.ndim == 1:
+        data = data.reshape((-1,1))
 
+    # get the number of overlapping windows that fit into the data
+    num_windows = (data.shape[0] - window_size) // (window_size - overlap_size) + 1
+    overhang = data.shape[0] - (num_windows*window_size - (num_windows-1)*overlap_size)
+
+    # if there's overhang, need an extra window and a zero pad on the data
+    if overhang != 0:
+        num_windows += 1
+        newdata = np.zeros((num_windows*window_size - (num_windows-1)*overlap_size,data.shape[1]))
+        newdata[:data.shape[0]] = data
+        data = newdata
+
+    sz = data.dtype.itemsize
+    ret = ast(
+            data,
+            shape=(num_windows,window_size*data.shape[1]),
+            strides=((window_size-overlap_size)*data.shape[1]*sz,sz)
+            )
+
+    if flatten_inside_window:
+        return ret
+    else:
+        return ret.reshape((num_windows,-1,data.shape[1]))
 
 def form_day(key):
     return str(key.month) + "/" + str(key.day)
@@ -607,12 +644,12 @@ def sort_dict_list(dict_list, k, reverse_param = True):
 def sort_dict_alphabetically(cur_dict):
     return {k: cur_dict[k] for k in sorted(cur_dict.keys())}
 
-def robust_mkdir(cur_dir):
-    if not os.path.exists(cur_dir):
-        lower_dir = os.path.dirname(cur_dir)
-        if not os.path.exists(lower_dir):
-            robust_mkdir(lower_dir)
-        os.mkdir(cur_dir)
+def robust_mkdir(desired_dir):
+    """
+    Create a directory whether or not it exists, and no matter how far down you want
+    """
+    return Path(desired_dir).mkdir(parents=True, exist_ok=True)
+
 
 def robust_rmdir(cur_dir):
     if os.path.exists(cur_dir):
@@ -772,5 +809,11 @@ def array_pop(X, idx):
     x_list.pop(idx)
     return np.array(x_list)
 
-
+def isdigit(s):
+    """
+    check if the number is a digit, including if it has a decimal place in it
+    :param s:
+    :return:
+    """
+    return s.replace('.','',1).isdigit()
 
